/* G-CTB GNU Contabilidad
 * Copyright (C) 2001 Branly Abendano, EPN Ingenieria Sistemas  
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public  
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of   
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include "TransaccionContable.h"

Gda_Recordset *GetListadoTotalDeTransaccionesContables (void)
{
  Gda_Recordset *grs;
  gint rc;
                                        
  	grs = gda_recordset_new();
  	gda_recordset_set_connection(GDA_RECORDSET(grs), cnc);
  	rc = gda_recordset_open_txt(GDA_RECORDSET(grs),
			      "SELECT 	T.CD_TRANSACCION_CONTABLE, T.CD_CTA_CONTABLE, C.NM_CTA_CONTABLE, T.DESCRIPCION,  
			       		T.COMPROBANTE, T.DIARIO,T.TP_TRANSACCION,T.VALOR, T.FE_TRANSACCION  
			       FROM 	TRANSACCION_CONTABLE T, CTA_CONTABLE C
			       WHERE 	C.CD_CTA_CONTABLE=T.CD_CTA_CONTABLE 
			       ORDER BY T.FE_TRANSACCION, T.CD_TRANSACCION_CONTABLE",
                              GDA_OPEN_STATIC,
                              GDA_LOCK_PESSIMISTIC,
                              0);
  	if (rc < 0) {
    		g_print("\nNo se pudo ejecutar la consulta.\n");
  	  	gtk_main_quit();
  	}

  	return GDA_RECORDSET(grs); 
}

gint GetNroRegistrosTransContablesDeCtasContables (gchar *CodigoCuenta)
{
  Gda_Recordset *grs;
  Gda_Field *field;
  gchar *ConsultaSelect = "SELECT COUNT(*) FROM TRANSACCION_CONTABLE WHERE CD_CTA_CONTABLE LIKE '";
  gchar *ConsultaTmp = NULL;
  gchar *ConsultaFinal = "%'";
  gchar *CadenaNroRegistros = NULL;
  gint rc;
  gint NroRegistros=0;
                                        
  	ConsultaTmp = g_strconcat(ConsultaSelect,CodigoCuenta,NULL);
  	ConsultaTmp = g_strconcat(ConsultaTmp,ConsultaFinal,NULL);

  	grs = gda_recordset_new();
  	gda_recordset_set_connection(GDA_RECORDSET(grs), cnc);
  	rc = gda_recordset_open_txt(GDA_RECORDSET(grs),
			      ConsultaTmp,
                              GDA_OPEN_STATIC,
                              GDA_LOCK_PESSIMISTIC,
                              0);
  	if (rc < 0) {
    		g_print("\nNo se pudo ejecutar la consulta.\n");
    		gtk_main_quit();
 	 }

        gda_recordset_move_next (grs);
   
        field = gda_recordset_field_idx (GDA_RECORDSET(grs), 0);
   
        if (gda_field_isnull(field))
                g_print("\nEl Campo es nulo");
   

        CadenaNroRegistros = (gchar *)gda_stringify_value(CadenaNroRegistros, 0, field);
                
        rc = sscanf(CadenaNroRegistros,"%d",&NroRegistros);   
        
  	gda_recordset_free (grs);

        return NroRegistros;
}

Gda_Recordset *GetListadoTotalDeTransaccionesContablesPorCtaContable (gchar *CodigoCtaContable)
{
  Gda_Recordset *grs;
  gchar *ConsultaSelect = "SELECT * FROM TRANSACCION_CONTABLE WHERE CD_CTA_CONTABLE='";
  gchar *ConsultaTmp = NULL;
  gchar *ConsultaFinal = "' ORDER BY FE_TRANSACCION";
  gint rc;

  	ConsultaTmp = g_strconcat(ConsultaSelect,CodigoCtaContable,NULL);
  	ConsultaTmp = g_strconcat(ConsultaTmp,ConsultaFinal,NULL);
 
  	grs = gda_recordset_new();
  	gda_recordset_set_connection(GDA_RECORDSET(grs), cnc);
  	rc = gda_recordset_open_txt(GDA_RECORDSET(grs),
			      ConsultaTmp,
                              GDA_OPEN_STATIC,
                              GDA_LOCK_PESSIMISTIC,
                              0);
  	if (rc < 0) {
    		g_print("\nNo se pudo ejecutar la consulta.\n");
    		gtk_main_quit();
  	}

  	return GDA_RECORDSET(grs); 
}

Gda_Recordset *GetListadoAsientoContable (gchar *Comprobante)
{
  Gda_Recordset *grs;
  gchar *ConsultaSelect = "SELECT T.CD_TRANSACCION_CONTABLE, T.CD_CTA_CONTABLE, C.NM_CTA_CONTABLE, T.DESCRIPCION,  T.COMPROBANTE,T.DIARIO,T.TP_TRANSACCION,T.VALOR, T.FE_TRANSACCION  FROM TRANSACCION_CONTABLE T, CTA_CONTABLE C WHERE  C.CD_CTA_CONTABLE=T.CD_CTA_CONTABLE AND T.COMPROBANTE='";
  gchar *ConsultaTmp = NULL;
  gchar *ConsultaFinal = "' ORDER BY T.CD_TRANSACCION_CONTABLE";
  gint rc;
                                        
  	ConsultaTmp = g_strconcat(ConsultaSelect,Comprobante,NULL);
  	ConsultaTmp = g_strconcat(ConsultaTmp,ConsultaFinal,NULL);
 
  	grs = gda_recordset_new();
  	gda_recordset_set_connection(GDA_RECORDSET(grs), cnc);
  	rc = gda_recordset_open_txt(GDA_RECORDSET(grs),
			      ConsultaTmp,
                              GDA_OPEN_STATIC,
                              GDA_LOCK_PESSIMISTIC,
                              0);
  	if (rc < 0) {
    		g_print("\nNo se pudo ejecutar la consulta.\n");
    		gtk_main_quit();
  	}

  	return GDA_RECORDSET(grs); 
}


gint InsertNuevoTransaccionContable (gchar *CodigoCtaContable, gchar *DescripcionTransaccion, gchar *ComprobanteTransaccion,
				     gchar *NombreDiarioTransaccion, gchar *ValorTransaccion, gchar *FechaTransaccion)
{
   gchar *ConsultaInicial = "INSERT INTO TRANSACCION_CONTABLE(CD_CTA_CONTABLE,COMPROBANTE,DESCRIPCION,DIARIO,TP_TRANSACCION,VALOR,FE_TRANSACCION) VALUES('";
   gchar *ConsultaTmp = NULL;
   gchar *TipoTransaccion = NULL;
   gfloat ValorTrans = 0;
        
   Gda_Recordset *grs;
   Gda_Command* cmd;
   gulong* n=0;
   gint rc=0;

        rc = sscanf(ValorTransaccion,"%f",&ValorTrans);

        if (rc == 0) {
                g_print("\nUn Error con ValorTransaccion=%s, y ValorTrans=%f",ValorTransaccion,ValorTrans);
        }

        if (ValorTrans > 0) {
                TipoTransaccion = "DEBE";
        } else {
                TipoTransaccion = "HABER";
        }
      
        ConsultaTmp = g_strconcat(ConsultaInicial,CodigoCtaContable,NULL);
        ConsultaTmp = g_strconcat(ConsultaTmp,"','",NULL);
        ConsultaTmp = g_strconcat(ConsultaTmp,ComprobanteTransaccion,NULL);
        ConsultaTmp = g_strconcat(ConsultaTmp,"','",NULL);
        ConsultaTmp = g_strconcat(ConsultaTmp,DescripcionTransaccion,NULL);
        ConsultaTmp = g_strconcat(ConsultaTmp,"','",NULL);
        ConsultaTmp = g_strconcat(ConsultaTmp,NombreDiarioTransaccion,NULL);
        ConsultaTmp = g_strconcat(ConsultaTmp,"','",NULL);
        ConsultaTmp = g_strconcat(ConsultaTmp,TipoTransaccion,NULL);
        ConsultaTmp = g_strconcat(ConsultaTmp,"',",NULL);
        ConsultaTmp = g_strconcat(ConsultaTmp,ValorTransaccion,NULL);
        ConsultaTmp = g_strconcat(ConsultaTmp,",'",NULL);
        ConsultaTmp = g_strconcat(ConsultaTmp,FechaTransaccion,NULL);
        ConsultaTmp = g_strconcat(ConsultaTmp,"')",NULL);
        
        grs = gda_recordset_new();
        gda_recordset_set_connection(GDA_RECORDSET(grs), cnc);

        cmd = gda_command_new();
        gda_command_set_connection (cmd,cnc);
        gda_command_set_text(cmd,ConsultaTmp);
   
        gda_connection_begin_transaction (cnc);
        grs = gda_command_execute(cmd,&n,0);
        gda_connection_commit_transaction (cnc);

	return 0;
}

gint DeleteTransaccionContable (gchar *CodigoTransaccionContable)
{
   gulong* n=0;
   gchar *ConsultaInicial = "DELETE FROM TRANSACCION_CONTABLE WHERE CD_TRANSACCION_CONTABLE='";
   gchar *ConsultaTmp = NULL;

   Gda_Recordset *grs;
   Gda_Command* cmd;
 
   
        ConsultaTmp = g_strconcat(ConsultaInicial,CodigoTransaccionContable,NULL);
 
        grs = gda_recordset_new();
        gda_recordset_set_connection(GDA_RECORDSET(grs), cnc);
 
        cmd = gda_command_new();
        gda_command_set_connection (cmd,cnc);
        gda_command_set_text(cmd,ConsultaTmp);
   
        gda_connection_begin_transaction (cnc);
        grs = gda_command_execute(cmd,&n,0);
        gda_connection_commit_transaction (cnc);
   
	return 0;

}

gint SetearAsientoCuandrado (gchar *ComprobanteContable)
{
   gulong* n=0;
   gchar *ConsultaInicial = "UPDATE TRANSACCION_CONTABLE SET ASIENTO_CUADRADO='S' WHERE COMPROBANTE='";
   gchar *ConsultaTmp = NULL;

   Gda_Recordset *grs;
   Gda_Command* cmd;
 

       	ConsultaTmp = g_strconcat(ConsultaInicial,ComprobanteContable,NULL);
      	ConsultaTmp = g_strconcat(ConsultaTmp,"'",NULL);
   
        grs = gda_recordset_new();
        gda_recordset_set_connection(GDA_RECORDSET(grs), cnc);
 
        cmd = gda_command_new();
        gda_command_set_connection (cmd,cnc);
        gda_command_set_text(cmd,ConsultaTmp);
   
        gda_connection_begin_transaction (cnc);
        grs = gda_command_execute(cmd,&n,0);
        gda_connection_commit_transaction (cnc);
   
	return 0;

}

gfloat ConsultarTotalDebeAsientoContable(gchar* Comprobante)
{
   Gda_Recordset *grs;
   gint rc;
   gchar *ConsultaInicial = "SELECT SUM(VALOR) FROM TRANSACCION WHERE TP_TRANSACCION='DEBE' AND COMPROBANTE='";
   gchar *ConsultaTmp = NULL;
   gfloat TotalDebeAsientoContable = 0;
   gchar *CadenaDebe = NULL;
   Gda_Field *field;
        
        ConsultaTmp = g_strconcat(ConsultaInicial,Comprobante,NULL);
        ConsultaTmp = g_strconcat(ConsultaTmp,"'",NULL);
        
        grs = gda_recordset_new();
        gda_recordset_set_connection(GDA_RECORDSET(grs), cnc);
        rc = gda_recordset_open_txt(GDA_RECORDSET(grs),
                                        ConsultaTmp,  
                                        GDA_OPEN_DYNAMIC,
                                        GDA_LOCK_PESSIMISTIC,
                                        0);
   
        gda_recordset_move_next (grs);
   
        field = gda_recordset_field_idx (GDA_RECORDSET(grs), 0);

        if (gda_field_isnull(field))
                g_print("\nEl Campo es nulo");

        CadenaDebe = (gchar *)gda_stringify_value(CadenaDebe, 0, field);
   
        rc = sscanf(CadenaDebe,"%f",&TotalDebeAsientoContable);
        
        return TotalDebeAsientoContable;
        
}
        
gfloat ConsultarTotalHaberAsientoContable(gchar* Comprobante)
{
   Gda_Recordset *grs;
   gint rc;
   gchar *ConsultaInicial = "SELECT SUM(VALOR) FROM TRANSACCION WHERE TP_TRANSACCION='HABER' AND COMPROBANTE='";
   gchar *ConsultaTmp = NULL;
   gfloat TotalHaberAsientoContable = 0;
   gchar *CadenaHaber = NULL;
   Gda_Field *field;
                
        ConsultaTmp = g_strconcat(ConsultaInicial,Comprobante,NULL);
        ConsultaTmp = g_strconcat(ConsultaTmp,"'",NULL);
   
        grs = gda_recordset_new();
        gda_recordset_set_connection(GDA_RECORDSET(grs), cnc);
        rc = gda_recordset_open_txt(GDA_RECORDSET(grs),
                                        ConsultaTmp,
                                        GDA_OPEN_DYNAMIC,
                                        GDA_LOCK_PESSIMISTIC,
                                        0);

        gda_recordset_move_next (grs);
   
        field = gda_recordset_field_idx (GDA_RECORDSET(grs), 0);
   
        if (gda_field_isnull(field))
                g_print("\nEl Campo es nulo");
   

        CadenaHaber = (gchar *)gda_stringify_value(CadenaHaber, 0, field);
                
        rc = sscanf(CadenaHaber,"%f",&TotalHaberAsientoContable);   
        
        return TotalHaberAsientoContable;
        
}

gfloat ConsultarTotalDebeTransaccion(gchar *CodigoCtaContable)
{
   Gda_Recordset *grs;
   gint rc;
   gchar *ConsultaInicial = "SELECT SUM(VALOR) FROM TRANSACCION_CONTABLE WHERE TP_TRANSACCION='DEBE' AND CD_CTA_CONTABLE='";
   gchar *ConsultaTmp = NULL;
   gfloat TotalDebe = 0;
   gchar *CadenaDebe = NULL;
   Gda_Field *field;
        
        ConsultaTmp = g_strconcat(ConsultaInicial,CodigoCtaContable,NULL);
        ConsultaTmp = g_strconcat(ConsultaTmp,"'",NULL);
        
        grs = gda_recordset_new();
        gda_recordset_set_connection(GDA_RECORDSET(grs), cnc);
        rc = gda_recordset_open_txt(GDA_RECORDSET(grs),
                                        ConsultaTmp,  
                                        GDA_OPEN_DYNAMIC,
                                        GDA_LOCK_PESSIMISTIC,
                                        0);
   
        gda_recordset_move_next (grs);
   
        field = gda_recordset_field_idx (GDA_RECORDSET(grs), 0);

        if (gda_field_isnull(field))
                g_print("\nEl Campo es nulo");

        CadenaDebe = (gchar *)gda_stringify_value(CadenaDebe, 0, field);
   
        rc = sscanf(CadenaDebe,"%f",&TotalDebe);
        
        return TotalDebe;
        
}
        
gfloat ConsultarTotalHaberTransaccion(gchar *CodigoCtaContable)
{
   Gda_Recordset *grs;
   gint rc;
   gchar *ConsultaInicial = "SELECT SUM(VALOR) FROM TRANSACCION_CONTABLE WHERE TP_TRANSACCION='HABER' AND CD_CTA_CONTABLE='";
   gchar *ConsultaTmp = NULL;
   gfloat TotalHaber = 0;
   gchar *CadenaHaber = NULL;
   Gda_Field *field;
                
        ConsultaTmp = g_strconcat(ConsultaInicial,CodigoCtaContable,NULL);
        ConsultaTmp = g_strconcat(ConsultaTmp,"'",NULL);
   
        grs = gda_recordset_new();
        gda_recordset_set_connection(GDA_RECORDSET(grs), cnc);
        rc = gda_recordset_open_txt(GDA_RECORDSET(grs),
                                        ConsultaTmp,
                                        GDA_OPEN_DYNAMIC,
                                        GDA_LOCK_PESSIMISTIC,
                                        0);

        gda_recordset_move_next (grs);
   
        field = gda_recordset_field_idx (GDA_RECORDSET(grs), 0);
   
        if (gda_field_isnull(field))
                g_print("\nEl Campo es nulo");
   

        CadenaHaber = (gchar *)gda_stringify_value(CadenaHaber, 0, field);
                
        rc = sscanf(CadenaHaber,"%f",&TotalHaber);   
        
        return TotalHaber;
        
}

gint SeteoAsientoCuadrado_PorComprobante_EnTransContable (gchar *Comprobante)
{
   gchar *ConsultaInicial = "UPDATE TRANSACCION_CONTABLE SET ASIENTO_CUADRADO='S' WHERE COMPROBANTE='";
   gchar *ConsultaTmp = NULL;
        
   Gda_Recordset *grs;
   Gda_Command* cmd;
   gulong* n=0;

        ConsultaTmp = g_strconcat(ConsultaInicial,Comprobante,NULL);
        ConsultaTmp = g_strconcat(ConsultaTmp,"'",NULL);
        
        grs = gda_recordset_new();
        gda_recordset_set_connection(GDA_RECORDSET(grs), cnc);

        cmd = gda_command_new();
        gda_command_set_connection (cmd,cnc);
        gda_command_set_text(cmd,ConsultaTmp);
   
        gda_connection_begin_transaction (cnc);
        grs = gda_command_execute(cmd,&n,0);
        gda_connection_commit_transaction (cnc);

	return 0;
}


gfloat ConsultarDebeTotalEntreDosFechas(gchar *FechaInicio, gchar *FechaFinal)
{
   Gda_Recordset *grs;
   gint rc;
   gchar *ConsultaInicial = "SELECT SUM(VALOR) FROM TRANSACCION_CONTABLE WHERE TP_TRANSACCION='DEBE' AND FE_TRANSACCION > '";
   gchar *ConsultaTmp = NULL;
   gfloat TotalDebe = 0;
   gchar *CadenaDebe = NULL;
   Gda_Field *field;
        
        ConsultaTmp = g_strconcat(ConsultaInicial,FechaInicio,NULL);
        ConsultaTmp = g_strconcat(ConsultaTmp,"' AND FE_TRANSACCION <='",NULL);
        ConsultaTmp = g_strconcat(ConsultaInicial,FechaFinal,NULL);
        ConsultaTmp = g_strconcat(ConsultaTmp,"'",NULL);
        
        grs = gda_recordset_new();
        gda_recordset_set_connection(GDA_RECORDSET(grs), cnc);
        rc = gda_recordset_open_txt(GDA_RECORDSET(grs),
                                        ConsultaTmp,  
                                        GDA_OPEN_DYNAMIC,
                                        GDA_LOCK_PESSIMISTIC,
                                        0);
   
        gda_recordset_move_next (grs);
   
        field = gda_recordset_field_idx (GDA_RECORDSET(grs), 0);

        if (gda_field_isnull(field))
                g_print("\nEl Campo es nulo");

        CadenaDebe = (gchar *)gda_stringify_value(CadenaDebe, 0, field);
   
        rc = sscanf(CadenaDebe,"%f",&TotalDebe);
        
        return TotalDebe;
        
}

gfloat ConsultarHaberTotalEntreDosFechas(gchar *FechaInicio, gchar *FechaFinal)
{
   Gda_Recordset *grs;
   gint rc;
   gchar *ConsultaInicial = "SELECT SUM(VALOR) FROM TRANSACCION_CONTABLE WHERE TP_TRANSACCION='HABER' AND FE_TRANSACCION > '";
   gchar *ConsultaTmp = NULL;
   gfloat TotalHaber = 0;
   gchar *CadenaHaber = NULL;
   Gda_Field *field;
        
        ConsultaTmp = g_strconcat(ConsultaInicial,FechaInicio,NULL);
        ConsultaTmp = g_strconcat(ConsultaTmp,"' AND FE_TRANSACCION <='",NULL);
        ConsultaTmp = g_strconcat(ConsultaInicial,FechaFinal,NULL);
        ConsultaTmp = g_strconcat(ConsultaTmp,"'",NULL);
        
        grs = gda_recordset_new();
        gda_recordset_set_connection(GDA_RECORDSET(grs), cnc);
        rc = gda_recordset_open_txt(GDA_RECORDSET(grs),
                                        ConsultaTmp,  
                                        GDA_OPEN_DYNAMIC,
                                        GDA_LOCK_PESSIMISTIC,
                                        0);
   
        gda_recordset_move_next (grs);
   
        field = gda_recordset_field_idx (GDA_RECORDSET(grs), 0);

        if (gda_field_isnull(field))
                g_print("\nEl Campo es nulo");

        CadenaHaber = (gchar *)gda_stringify_value(CadenaHaber, 0, field);
   
        rc = sscanf(CadenaHaber,"%f",&TotalHaber);
        
        return TotalHaber;
        
}
        
gfloat ConsultarDebeTotalMenorAUnaFecha(gchar *FechaInicio)
{
   Gda_Recordset *grs;
   gint rc;
   gchar *ConsultaInicial = "SELECT SUM(VALOR) FROM TRANSACCION_CONTABLE WHERE TP_TRANSACCION='DEBE' AND FE_TRANSACCION < '";
   gchar *ConsultaTmp = NULL;
   gfloat TotalDebe = 0;
   gchar *CadenaDebe = NULL;
   Gda_Field *field;
        
        ConsultaTmp = g_strconcat(ConsultaInicial,FechaInicio,NULL);
        ConsultaTmp = g_strconcat(ConsultaTmp,"'",NULL);
        
        grs = gda_recordset_new();
        gda_recordset_set_connection(GDA_RECORDSET(grs), cnc);
        rc = gda_recordset_open_txt(GDA_RECORDSET(grs),
                                        ConsultaTmp,  
                                        GDA_OPEN_DYNAMIC,
                                        GDA_LOCK_PESSIMISTIC,
                                        0);
   
        gda_recordset_move_next (grs);
   
        field = gda_recordset_field_idx (GDA_RECORDSET(grs), 0);

        if (gda_field_isnull(field))
                g_print("\nEl Campo es nulo");

        CadenaDebe = (gchar *)gda_stringify_value(CadenaDebe, 0, field);
   
        rc = sscanf(CadenaDebe,"%f",&TotalDebe);
        
        return TotalDebe;
        
}

gfloat ConsultarHaberTotalMenorAUnaFecha(gchar *FechaInicio)
{
   Gda_Recordset *grs;
   gint rc;
   gchar *ConsultaInicial = "SELECT SUM(VALOR) FROM TRANSACCION_CONTABLE WHERE TP_TRANSACCION='HABER' AND FE_TRANSACCION < '";
   gchar *ConsultaTmp = NULL;
   gfloat TotalHaber = 0;
   gchar *CadenaHaber = NULL;
   Gda_Field *field;
        
        ConsultaTmp = g_strconcat(ConsultaInicial,FechaInicio,NULL);
        ConsultaTmp = g_strconcat(ConsultaTmp,"'",NULL);
        
        grs = gda_recordset_new();
        gda_recordset_set_connection(GDA_RECORDSET(grs), cnc);
        rc = gda_recordset_open_txt(GDA_RECORDSET(grs),
                                        ConsultaTmp,  
                                        GDA_OPEN_DYNAMIC,
                                        GDA_LOCK_PESSIMISTIC,
                                        0);
   
        gda_recordset_move_next (grs);
   
        field = gda_recordset_field_idx (GDA_RECORDSET(grs), 0);

        if (gda_field_isnull(field))
                g_print("\nEl Campo es nulo");

        CadenaHaber = (gchar *)gda_stringify_value(CadenaHaber, 0, field);
   
        rc = sscanf(CadenaHaber,"%f",&TotalHaber);
        
        return TotalHaber;
        
}

gfloat ConsultarDebeCtaContableEntreDosFechas(gchar *FechaInicio, gchar *FechaFinal, gchar *CodigoCtaContable)
{
   Gda_Recordset *grs;
   gint rc;
   gchar *ConsultaInicial = "SELECT SUM(VALOR) FROM TRANSACCION_CONTABLE WHERE TP_TRANSACCION='DEBE' AND FE_TRANSACCION > '";
   gchar *ConsultaTmp = NULL;
   gfloat TotalDebe = 0;
   gchar *CadenaDebe = NULL;
   Gda_Field *field;
        
        ConsultaTmp = g_strconcat(ConsultaInicial,FechaInicio,NULL);
        ConsultaTmp = g_strconcat(ConsultaTmp,"' AND FE_TRANSACCION <='",NULL);
        ConsultaTmp = g_strconcat(ConsultaInicial,FechaFinal,NULL);
        ConsultaTmp = g_strconcat(ConsultaTmp,"' AND CD_CTA_CONTABLE LIKE '",NULL);
        ConsultaTmp = g_strconcat(ConsultaInicial,CodigoCtaContable,NULL);
        ConsultaTmp = g_strconcat(ConsultaTmp,"'",NULL);
        
        grs = gda_recordset_new();
        gda_recordset_set_connection(GDA_RECORDSET(grs), cnc);
        rc = gda_recordset_open_txt(GDA_RECORDSET(grs),
                                        ConsultaTmp,  
                                        GDA_OPEN_DYNAMIC,
                                        GDA_LOCK_PESSIMISTIC,
                                        0);
   
        gda_recordset_move_next (grs);
   
        field = gda_recordset_field_idx (GDA_RECORDSET(grs), 0);

        if (gda_field_isnull(field))
                g_print("\nEl Campo es nulo");

        CadenaDebe = (gchar *)gda_stringify_value(CadenaDebe, 0, field);
   
        rc = sscanf(CadenaDebe,"%f",&TotalDebe);
        
        return TotalDebe;
        
}

gfloat ConsultarHaberCtaContableEntreDosFechas(gchar *FechaInicio, gchar *FechaFinal, gchar *CodigoCtaContable)
{
   Gda_Recordset *grs;
   gint rc;
   gchar *ConsultaInicial = "SELECT SUM(VALOR) FROM TRANSACCION_CONTABLE WHERE TP_TRANSACCION='HABER' AND FE_TRANSACCION > '";
   gchar *ConsultaTmp = NULL;
   gfloat TotalHaber = 0;
   gchar *CadenaHaber = NULL;
   Gda_Field *field;
        
        ConsultaTmp = g_strconcat(ConsultaInicial,FechaInicio,NULL);
        ConsultaTmp = g_strconcat(ConsultaTmp,"' AND FE_TRANSACCION <='",NULL);
        ConsultaTmp = g_strconcat(ConsultaInicial,FechaFinal,NULL);
        ConsultaTmp = g_strconcat(ConsultaTmp,"' AND CD_CTA_CONTABLE LIKE '",NULL);
        ConsultaTmp = g_strconcat(ConsultaInicial,CodigoCtaContable,NULL);
        ConsultaTmp = g_strconcat(ConsultaTmp,"'",NULL);
        
        grs = gda_recordset_new();
        gda_recordset_set_connection(GDA_RECORDSET(grs), cnc);
        rc = gda_recordset_open_txt(GDA_RECORDSET(grs),
                                        ConsultaTmp,  
                                        GDA_OPEN_DYNAMIC,
                                        GDA_LOCK_PESSIMISTIC,
                                        0);
   
        gda_recordset_move_next (grs);
   
        field = gda_recordset_field_idx (GDA_RECORDSET(grs), 0);

        if (gda_field_isnull(field))
                g_print("\nEl Campo es nulo");

        CadenaHaber = (gchar *)gda_stringify_value(CadenaHaber, 0, field);
   
        rc = sscanf(CadenaHaber,"%f",&TotalHaber);
        
        return TotalHaber;
        
}

gfloat ConsultarDebeCtaContableEntreDosFechasIntermedio(gchar *FechaInicio, gchar *FechaFinal, gchar *CodigoCtaContable)
{
   Gda_Recordset *grs;
   gint rc;
   gchar *ConsultaInicial = "SELECT SUM(VALOR) FROM TRANSACCION_CONTABLE WHERE TP_TRANSACCION='DEBE' AND FE_TRANSACCION > '";
   gchar *ConsultaTmp = NULL;
   gfloat TotalDebe = 0;
   gchar *CadenaDebe = NULL;
   Gda_Field *field;
        
        ConsultaTmp = g_strconcat(ConsultaInicial,FechaInicio,NULL);
        ConsultaTmp = g_strconcat(ConsultaTmp,"' AND FE_TRANSACCION <'",NULL);
        ConsultaTmp = g_strconcat(ConsultaInicial,FechaFinal,NULL);
        ConsultaTmp = g_strconcat(ConsultaTmp,"' AND CD_CTA_CONTABLE='",NULL);
        ConsultaTmp = g_strconcat(ConsultaInicial,CodigoCtaContable,NULL);
        ConsultaTmp = g_strconcat(ConsultaTmp,"'",NULL);
        
        grs = gda_recordset_new();
        gda_recordset_set_connection(GDA_RECORDSET(grs), cnc);
        rc = gda_recordset_open_txt(GDA_RECORDSET(grs),
                                        ConsultaTmp,  
                                        GDA_OPEN_DYNAMIC,
                                        GDA_LOCK_PESSIMISTIC,
                                        0);
   
        gda_recordset_move_next (grs);
   
        field = gda_recordset_field_idx (GDA_RECORDSET(grs), 0);

        if (gda_field_isnull(field))
                g_print("\nEl Campo es nulo");

        CadenaDebe = (gchar *)gda_stringify_value(CadenaDebe, 0, field);
   
        rc = sscanf(CadenaDebe,"%f",&TotalDebe);
        
        return TotalDebe;
        
}

gfloat ConsultarHaberCtaContableEntreDosFechasIntermedio(gchar *FechaInicio, gchar *FechaFinal, gchar *CodigoCtaContable)
{
   Gda_Recordset *grs;
   gint rc;
   gchar *ConsultaInicial = "SELECT SUM(VALOR) FROM TRANSACCION_CONTABLE WHERE TP_TRANSACCION='HABER' AND FE_TRANSACCION > '";
   gchar *ConsultaTmp = NULL;
   gfloat TotalHaber = 0;
   gchar *CadenaHaber = NULL;
   Gda_Field *field;
        
        ConsultaTmp = g_strconcat(ConsultaInicial,FechaInicio,NULL);
        ConsultaTmp = g_strconcat(ConsultaTmp,"' AND FE_TRANSACCION <'",NULL);
        ConsultaTmp = g_strconcat(ConsultaInicial,FechaFinal,NULL);
        ConsultaTmp = g_strconcat(ConsultaTmp,"' AND CD_CTA_CONTABLE='",NULL);
        ConsultaTmp = g_strconcat(ConsultaInicial,CodigoCtaContable,NULL);
        ConsultaTmp = g_strconcat(ConsultaTmp,"'",NULL);
        
        grs = gda_recordset_new();
        gda_recordset_set_connection(GDA_RECORDSET(grs), cnc);
        rc = gda_recordset_open_txt(GDA_RECORDSET(grs),
                                        ConsultaTmp,  
                                        GDA_OPEN_DYNAMIC,
                                        GDA_LOCK_PESSIMISTIC,
                                        0);
   
        gda_recordset_move_next (grs);
   
        field = gda_recordset_field_idx (GDA_RECORDSET(grs), 0);

        if (gda_field_isnull(field))
                g_print("\nEl Campo es nulo");

        CadenaHaber = (gchar *)gda_stringify_value(CadenaHaber, 0, field);
   
        rc = sscanf(CadenaHaber,"%f",&TotalHaber);
        
        return TotalHaber;
        
}



gfloat ConsultarDebeTotalCtaContableMenorAFecha(gchar *CodigoCtaContable, gchar *FechaFinal)
{
   Gda_Recordset *grs;
   gint rc;
   gchar *ConsultaInicial = "SELECT SUM(VALOR) FROM TRANSACCION_CONTABLE WHERE TP_TRANSACCION='DEBE' AND CD_CTA_CONTABLE='";
   gchar *ConsultaTmp = NULL;
   gfloat TotalDebe = 0;
   gchar *CadenaDebe = NULL;
   Gda_Field *field;
        
        ConsultaTmp = g_strconcat(ConsultaInicial,CodigoCtaContable,NULL);
        ConsultaTmp = g_strconcat(ConsultaTmp,"' AND FE_TRANSACCION <='",NULL);
        ConsultaTmp = g_strconcat(ConsultaTmp,FechaFinal,NULL);
        ConsultaTmp = g_strconcat(ConsultaTmp,"'",NULL);
        
        grs = gda_recordset_new();
        gda_recordset_set_connection(GDA_RECORDSET(grs), cnc);
        rc = gda_recordset_open_txt(GDA_RECORDSET(grs),
                                        ConsultaTmp,  
                                        GDA_OPEN_DYNAMIC,
                                        GDA_LOCK_PESSIMISTIC,
                                        0);
   
        gda_recordset_move_next (grs);
   
        field = gda_recordset_field_idx (GDA_RECORDSET(grs), 0);

        if (gda_field_isnull(field))
                g_print("\nEl Campo es nulo");

        CadenaDebe = (gchar *)gda_stringify_value(CadenaDebe, 0, field);
   
        rc = sscanf(CadenaDebe,"%f",&TotalDebe);
        
        return TotalDebe;
        
}

gfloat ConsultarHaberTotalCtaContableMenorAFecha(gchar *CodigoCtaContable, gchar *FechaFinal)
{
   Gda_Recordset *grs;
   gint rc;
   gchar *ConsultaInicial = "SELECT SUM(VALOR) FROM TRANSACCION_CONTABLE WHERE TP_TRANSACCION='HABER' AND CD_CTA_CONTABLE='";
   gchar *ConsultaTmp = NULL;
   gfloat TotalHaber = 0;
   gchar *CadenaHaber = NULL;
   Gda_Field *field;
        
        ConsultaTmp = g_strconcat(ConsultaInicial,CodigoCtaContable,NULL);
        ConsultaTmp = g_strconcat(ConsultaTmp,"' AND FE_TRANSACCION <='",NULL);
        ConsultaTmp = g_strconcat(ConsultaTmp,FechaFinal,NULL);
        ConsultaTmp = g_strconcat(ConsultaTmp,"'",NULL);
        
        grs = gda_recordset_new();
        gda_recordset_set_connection(GDA_RECORDSET(grs), cnc);
        rc = gda_recordset_open_txt(GDA_RECORDSET(grs),
                                        ConsultaTmp,  
                                        GDA_OPEN_DYNAMIC,
                                        GDA_LOCK_PESSIMISTIC,
                                        0);
   
        gda_recordset_move_next (grs);
   
        field = gda_recordset_field_idx (GDA_RECORDSET(grs), 0);

        if (gda_field_isnull(field))
                g_print("\nEl Campo es nulo");

        CadenaHaber = (gchar *)gda_stringify_value(CadenaHaber, 0, field);
   
        rc = sscanf(CadenaHaber,"%f",&TotalHaber);
        
        return TotalHaber;
        
}


